@@ -1,9 +1,9 @@
-/*  
+/*
     GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2005  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: g3_model_revision.cpp,v 1.3 2007/06/26 15:04:10 cepek Exp $
- */
-
 #include <gnu_gama/g3/g3_model.h>
 #include <gnu_gama/g3/g3_cluster.h>
 #include <gnu_gama/outstream.h>
@@ -34,10 +30,10 @@ using namespace std;
 using namespace GNU_gama::g3;
 
 
-namespace 
+namespace
 {
-  class Revision :  
-    public GNU_gama::ObservationVisitor,
+  class Revision :
+    public GNU_gama::BaseVisitor,
     public GNU_gama::Visitor<Angle>,
     public GNU_gama::Visitor<Azimuth>,
     public GNU_gama::Visitor<Distance>,
@@ -53,35 +49,35 @@ namespace
 
     void visit(Angle* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(Azimuth* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(Distance* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(Height* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(HeightDiff* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(Vector* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(XYZ* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
     void visit(ZenithAngle* p)
     {
-      model->revision(p); 
+      model->revision(p);
     }
 
   private:
@@ -103,18 +99,18 @@ void Model::update_observations()
 
 
   ::Revision revision(this);
-  for (Model::ObservationData::iterator 
+  for (Model::ObservationData::iterator
          i=obsdata.begin(), e=obsdata.end(); i!=e; ++i)
     {
       (*i)->accept(&revision);
     }
 
-  for (Model::ClusterList::iterator ci = obsdata.clusters.begin(), 
+  for (Model::ClusterList::iterator ci = obsdata.clusters.begin(),
          ce = obsdata.clusters.end(); ci!=ce; ++ci)
     {
       (*ci)->update();
     }
-  
+
   return next_state_(obsrvs_);
 }
 
@@ -153,7 +149,7 @@ bool Model::revision(Angle* angle)
   update_index(right->U);
 
   dm_rows += angle->dimension();      // design matrix
-   
+
   if (from ->free_position()) dm_floats += 2;
   if (from ->free_height  ()) dm_floats += 1;
   if (left ->free_position()) dm_floats += 2;
@@ -169,10 +165,10 @@ bool Model::revision(Angle* angle)
 bool Model::revision(Azimuth* a)
 {
   if (!a->active()) return false;
-  
+
   Point* from = points->find(a->from);
   Point* to   = points->find(a->to  );
-  
+
   if ( from == 0      ||  to == 0      ) return a->set_active(false);
   if ( from->unused() ||  to->unused() ) return a->set_active(false);
   if (!from->has_position()            ) return a->set_active(false);
@@ -186,7 +182,7 @@ bool Model::revision(Azimuth* a)
   update_index(to  ->N);
   update_index(to  ->E);
   update_index(to  ->U);
-  
+
   dm_rows += a->dimension();            // design matrix
 
   if (from->free_horizontal_position())  dm_floats += 2;
@@ -202,10 +198,10 @@ bool Model::revision(Azimuth* a)
 bool Model::revision(Distance* d)
 {
   if (!d->active()) return false;
-  
+
   Point* from = points->find(d->from);
   Point* to   = points->find(d->to  );
-  
+
   if ( from == 0      ||  to == 0      ) return d->set_active(false);
   if ( from->unused() ||  to->unused() ) return d->set_active(false);
   if (!from->has_position()            ) return d->set_active(false);
@@ -219,7 +215,7 @@ bool Model::revision(Distance* d)
   update_index(to  ->N);
   update_index(to  ->E);
   update_index(to  ->U);
-  
+
   dm_rows += d->dimension();            // design matrix
 
   if (from->free_horizontal_position())  dm_floats += 2;
@@ -233,11 +229,11 @@ bool Model::revision(Distance* d)
 
 
 bool Model::revision(Height* height)
-{  
+{
   if (!height->active()) return false;
-  
+
   Point* point = points->find(height->id);
-  
+
   if ( point == 0                ) return height->set_active(false);
   if ( point->unused()           ) return height->set_active(false);
   if (!point->test_model_height()) return height->set_active(false);
@@ -245,7 +241,7 @@ bool Model::revision(Height* height)
   active_obs->push_back(height);
 
   update_index(point->U);
-  
+
   dm_rows += height->dimension();      // design matrix
 
   if (point->free_height()) dm_floats += 1;
@@ -258,10 +254,10 @@ bool Model::revision(Height* height)
 bool Model::revision(HeightDiff* dh)
 {
   if (!dh->active()) return false;
-  
+
   Point* from = points->find(dh->from);
   Point* to   = points->find(dh->to  );
-  
+
   if ( from == 0      ||  to == 0     ) return dh->set_active(false);
   if ( from->unused() ||  to->unused()) return dh->set_active(false);
   if (!from->test_model_height()      ) return dh->set_active(false);
@@ -271,7 +267,7 @@ bool Model::revision(HeightDiff* dh)
 
   update_index(from->U);
   update_index(to  ->U);
-  
+
   dm_rows += dh->dimension();            // design matrix
 
   if (from->free_height())               dm_floats += 1;
@@ -343,10 +339,10 @@ bool Model::revision(XYZ* xyz)
 bool Model::revision(ZenithAngle* z)
 {
   if (!z->active()) return false;
-  
+
   Point* from = points->find(z->from);
   Point* to   = points->find(z->to  );
-  
+
   if ( from == 0      ||  to == 0      ) return z->set_active(false);
   if ( from->unused() ||  to->unused() ) return z->set_active(false);
   if (!from->has_position()            ) return z->set_active(false);
@@ -360,7 +356,7 @@ bool Model::revision(ZenithAngle* z)
   update_index(to  ->N);
   update_index(to  ->E);
   update_index(to  ->U);
-  
+
   dm_rows += z->dimension();            // design matrix
 
   if (from->free_horizontal_position())  dm_floats += 2;
