@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2005  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2005, 2018  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -15,8 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <iomanip>
@@ -25,7 +24,7 @@
 #include <gnu_gama/g3/g3_write_observation_xml.h>
 #include <gnu_gama/outstream.h>
 #include <gnu_gama/adj/adj.h>
-#include <gnu_gama/xml/dataparser.h>
+#include <gnu_gama/xml/dataobject.h>
 
 using namespace std;
 using namespace GNU_gama::g3;
@@ -99,7 +98,7 @@ void Model::write_xml_adjustment_results(std::ostream& out)
 {
   if (!check_adjustment()) update_adjustment();
 
-  out << GNU_gama::DataParser::xml_start;
+  out << GNU_gama::DataObject::Base::xml_begin();
   out << "<g3-adjustment-results>\n";
 
   write_xml_rejected_observations          (out);
@@ -108,7 +107,8 @@ void Model::write_xml_adjustment_results(std::ostream& out)
   write_xml_adjustment_results_observations(out);
 
   out << "</g3-adjustment-results>\n";
-  out << GNU_gama::DataParser::xml_end;
+  out << GNU_gama::DataObject::Base::xml_end();
+
 }
 
 
