@@ -25,7 +25,7 @@
 
 using std::string;
 
-int main(int argc, char* argv[])
+int main(int /*argc*/, char* argv[])
 {
   int error = 0;
 
