@@ -109,7 +109,7 @@ int main()
         cout << MaxEl(B-C);
       }
       catch (Exception::matvec e) {
-        cout << " err = " << int(e.error) << " : " << e.description;
+        cout << " err = " << e.error() << " : " << e.what();
       }
       catch (...) {
         cout << "?????????????????????????????????\n";
